:orphan:

.. parade documentation master file, created by
   sphinx-quickstart on Sat Mar 17 22:00:09 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. image:: _static/parade.png
   :width: 200px
   :align: left

================================
Parade: Process data with Pandas
================================

Version: |version|

``Parade`` is a simple and out-of-box toolkit to handle data work such as ETL, data analysis, BI reports,
etc, and enable fast and flexible integration mechanism with applications. It can be used for a wide
range of purposes, from composing & scheduling data workflow to providing unified web-APIs of data query.

This documentation contains everything you need to know about Parade.

.. toctree::
   :caption: First steps

   first/install

   first/tutorial

.. toctree::
   :caption: Command line references

   TODO

.. toctree::
   :caption: Concepts & Architecture

   TODO

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
